/**
 * @file adc.h
 * @brief ADC Module header
 *
 * Proyecto Smart Watch - ADC
 * ADC module
 *
 * This module is used to configure the
 * ADC14, start adc conversion and get last temperature using the internal sensor
 *
 * adc.h
 * Module that allows the configuration of the ADC14 and getting the temperature reading
 *
 * @authors Leonardo Martínez <leonardo.martinez.hornak@fing.edu.uy>, Isabel Morales <imorales@fing.edu.uy>
 * @version 1.0
 * @date May 15, 2021
 */

#ifndef INCLUDE_ADC_H_
#define INCLUDE_ADC_H_

/**
 * @brief Initializes REFA and ADC14, configuring it to use the temperature sensor
 */
void initializeADC();

/**
 * @brief Sets callback function to be added from this module to the function queue
 * @param void* callback_function: function to be called when a temperature reading is ready
 *
 */
void setTempCallbackFunction(void *callback_function);

/**
 * @brief Start ADC conversion
 */
void runADCConversion(void);

/**
 * @brief Obtains the last temperature reading in celsius
 * @return int temperature in celsius degrees
 *
 */
int getTemperatureReading(void);

#endif /* INCLUDE_ADC_H_ */
