/**
 * @file gpio.h
 * @brief GPIO Module header
 *
 * Proyecto Smart Watch - GPIO
 * GPIO module
 *
 * This module is used to configure the
 * GPIOS, modify LED states and get notifications for button touches
 *
 * gpio.h
 * Modules that allows the configuration of the GPIOs and getting the state of the
 * buttons.
 *
 * @authors Leonardo Martínez <leonardo.martinez.hornak@fing.edu.uy>, Isabel Morales <imorales@fing.edu.uy>
 * @version 1.0
 * @date May 15, 2021
 */

#ifndef INCLUDE_GPIO_H_
#define INCLUDE_GPIO_H_

/**
* Constants shared with other modules
*/
enum leds {LED_ONE, LED_RED, LED_GREEN, LED_BLUE};

/**
 * @brief Initializes all ports according to connection to MSP432 Launchpad and to save power of unused pins
 *
 */
void initializeGPIOModule(void);

/**
 * @brief Turn on LED specified by the identifier
 * @param int identifier: name of the LED as defined .common.h
 *
 */
void turnOnLED(int identifier);

/**
 * @brief Turn off LED specified by the identifier
 * @param int identifier: name of the LED as defined .common.h
 *
 */
void turnOffLED(int identifier);

/**
 * @brief Sets callback function to be added from this module to the function queue
 * @param void* callback_function: function to be called when the bluetooth init button is pressed
 *
 */
void setBluetoothButtonISRCallbackFunction(void *callback_function);



#endif /* INCLUDE_GPIO_H_ */
