/**
 * @file uart.h
 * @brief UART Module header
 *
 * Proyecto Smart Watch - UART
 * UART module
 *
 * This module is used to configure the
 * UART peripheral of the MSP432P401R, transmit data and receive data using the peripheral
 *
 * uart.h
 * Modules that allows the configuration of the UART peripheral of the MSP432P401R
 *
 * @authors Leonardo Martínez <leonardo.martinez.hornak@fing.edu.uy>, Isabel Morales <imorales@fing.edu.uy>
 * @version 1.0
 * @date May 15, 2021
 */

#ifndef INCLUDE_UART_H_
#define INCLUDE_UART_H_

/**
 * @brief Initializes UART module
 */
void initializeUART(void);

/**
 * @brief Sets callback function to be added from this module to the function queue
 * @param void* callback_function: function to be called when a new message is available
 *
 */
void setUartCallbackFunction(void *callback_function);

/**
 * @brief Sends a char array using UART module
 * @param char* buffer_pointer: auxiliary buffer pointer which contains data to be transmitted
 *
 */
void uartTransmit(char* buffer_pointer);

/**
 * @brief Copies message received by the UART module into an external char array indicated by buffer_pointer
 * @param char* buffer_pointer: auxiliary buffer pointer which points to the address to use for copying the message
 *
 */
void uartReceive(char* buffer_pointer);

#endif /* INCLUDE_UART_H_ */
